@@ -104,7 +104,7 @@ except ImportError:
                 " install ordereddict 1.1 from pypi for python2.6")
 
 __pkgname__ = 'python-crontab'
-__version__ = '2.2.0'
+__version__ = '2.2.1'
 
 ITEMREX = re.compile(r'^\s*([^@#\s]+)\s+([^@#\s]+)\s+([^@#\s]+)\s+([^@#\s]+)'
                      r'\s+([^@#\s]+)\s+([^#\n]*)(\s+#\s*([^\n]*)|$)')
@@ -273,8 +273,8 @@ class CronTab(object):
     def append(self, item, line='', read=False):
         """Append a CronItem object to this CronTab"""
         if item.is_valid():
-            for key in self._parked_env:
-                item.env[key] = self._parked_env.pop(key)
+            item.env.update(self._parked_env)
+            self._parked_env = OrderedDict()
 
             if read and not item.comment and self.lines and \
               self.lines[-1] and self.lines[-1][0] == '#':
@@ -291,8 +291,8 @@ class CronTab(object):
                 return None
 
         elif not self.crons and self._parked_env:
-            for key in self._parked_env:
-                self.env[key] = self._parked_env.pop(key)
+            self.env.update(self._parked_env)
+            self._parked_env = OrderedDict()
 
         self.lines.append(line.replace('\n', ''))
 
@@ -1257,7 +1257,7 @@ class OrderedVariableList(OrderedDict):
         previous = self.previous
         if key in self:
             return super(OrderedVariableList, self).__getitem__(key)
-        elif previous:
+        elif previous is not None:
             return previous.all()[key]
         raise KeyError("Environment Variable '%s' not found." % key)
 
